@@ -2,15 +2,10 @@ import json
 import time
 from typing import List, Tuple
 
-from instagrapi.exceptions import (
-    ClientError,
-    ClientNotFoundError,
-    LocationNotFound,
-)
+from instagrapi.exceptions import ClientError, ClientNotFoundError, LocationNotFound
 from instagrapi.extractors import extract_location, extract_media_v1
 from instagrapi.types import Location, Media
 
-
 tab_keys_a1 = ('edge_location_to_top_posts', 'edge_location_to_media')
 tab_keys_v1 = ('ranked', 'recent')
 
